==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/hu.py <==
info = {
    "name": "hu",
    "date_order": "YMD",
    "january": [
        "január",
        "jan",
        "I"
    ],
    "february": [
        "február",
        "febr",
        "feb",
        "II"
    ],
    "march": [
        "március",
        "márc",
        "már",
        "III"
    ],
    "april": [
        "április",
        "ápr",
        "IV"
    ],
    "may": [
        "május",
        "máj",
        "V"
    ],
    "june": [
        "június",
        "jún",
        "VI"
    ],
    "july": [
        "július",
        "júl",
        "VII"
    ],
    "august": [
        "augusztus",
        "aug",
        "VIII"
    ],
    "september": [
        "szeptember",
        "szept",
        "IX"
    ],
    "october": [
        "október",
        "okt",
        "X"
    ],
    "november": [
        "november",
        "nov",
        "XI"
    ],
    "december": [
        "december",
        "dec",
        "XII"
    ],
    "monday": [
        "hétfő",
        "h"
    ],
    "tuesday": [
        "kedd",
        "k"
    ],
    "wednesday": [
        "szerda",
        "sze"
    ],
    "thursday": [
        "csütörtök",
        "cs"
    ],
    "friday": [
        "péntek",
        "p"
    ],
    "saturday": [
        "szombat",
        "szo"
    ],
    "sunday": [
        "vasárnap",
        "v",
        "vas"
    ],
    "am": [
        "de"
    ],
    "pm": [
        "du"
    ],
    "year": [
        "év",
        "évek",
        "évvel",
        "éve"
    ],
    "month": [
        "hónap",
        "hó",
        "hónapok",
        "hónappal",
        "hónapja"
    ],
    "week": [
        "hét",
        "hetek",
        "héttel",
        "hete"
    ],
    "day": [
        "nap",
        "napok",
        "napja",
        "nappal"
    ],
    "hour": [
        "óra",
        "ó",
        "órák",
        "órája",
        "órával",
        "óráig",
        "órától"
    ],
    "minute": [
        "perc",
        "p",
        "percek",
        "perce",
        "perccel",
        "percig",
        "perctől"
    ],
    "second": [
        "másodperc",
        "mp",
        "másodpercek",
        "másodperce",
        "másodperccel",
        "másodpercig",
        "másodperctől"
    ],
    "relative-type": {
        "1 year ago": [
            "előző év"
        ],
        "0 year ago": [
            "ez az év"
        ],
        "in 1 year": [
            "következő év"
        ],
        "1 month ago": [
            "előző hónap"
        ],
        "0 month ago": [
            "ez a hónap"
        ],
        "in 1 month": [
            "következő hónap"
        ],
        "1 week ago": [
            "előző hét"
        ],
        "0 week ago": [
            "ez a hét"
        ],
        "in 1 week": [
            "következő hét"
        ],
        "1 day ago": [
            "tegnap"
        ],
        "0 day ago": [
            "ma"
        ],
        "in 1 day": [
            "holnap"
        ],
        "0 hour ago": [
            "ebben az órában"
        ],
        "0 minute ago": [
            "ebben a percben"
        ],
        "0 second ago": [
            "most"
        ],
        "2 day ago": [
            "tegnapelőtt"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) év múlva"
        ],
        "\\1 year ago": [
            "(\\d+) évvel ezelőtt"
        ],
        "in \\1 month": [
            "(\\d+) hónap múlva"
        ],
        "\\1 month ago": [
            "(\\d+) hónappal ezelőtt"
        ],
        "in \\1 week": [
            "(\\d+) hét múlva"
        ],
        "\\1 week ago": [
            "(\\d+) héttel ezelőtt"
        ],
        "in \\1 day": [
            "(\\d+) nap múlva"
        ],
        "\\1 day ago": [
            "(\\d+) nappal ezelőtt",
            "(\\d+) napja"
        ],
        "in \\1 hour": [
            "(\\d+) óra múlva"
        ],
        "\\1 hour ago": [
            "(\\d+) órával ezelőtt"
        ],
        "in \\1 minute": [
            "(\\d+) perc múlva"
        ],
        "\\1 minute ago": [
            "(\\d+) perccel ezelőtt"
        ],
        "in \\1 second": [
            "(\\d+) másodperc múlva"
        ],
        "\\1 second ago": [
            "(\\d+) másodperccel ezelőtt"
        ]
    },
    "locale_specific": {},
    "skip": [
        "-án",
        "-én",
        "-kor",
        "-a",
        "-je",
        "-i",
        "-ji",
        "-ei",
        "-jei",
        "-ától",
        "-étől",
        "-ai",
        "-től",
        "-tól",
        "-ig",
        "-áig",
        "-éig",
        "-akor",
        "-ekor",
        "-e",
        "-es",
        "-ös",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "ezelőtt"
    ],
    "in": [
        "múlva"
    ],
    "simplifications": [
        {
            "egy": "1"
        }
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/hu.py <==
info = {
    "name": "hu",
    "date_order": "YMD",
    "january": [
        "jan",
        "január",
        "I"
    ],
    "february": [
        "febr",
        "február",
        "feb",
        "II"
    ],
    "march": [
        "márc",
        "március",
        "már",
        "III"
    ],
    "april": [
        "ápr",
        "április",
        "IV"
    ],
    "may": [
        "máj",
        "május",
        "V"
    ],
    "june": [
        "jún",
        "június",
        "VI"
    ],
    "july": [
        "júl",
        "július",
        "VII"
    ],
    "august": [
        "aug",
        "augusztus",
        "VIII"
    ],
    "september": [
        "szept",
        "szeptember",
        "IX"
    ],
    "october": [
        "okt",
        "október",
        "X"
    ],
    "november": [
        "nov",
        "november",
        "XI"
    ],
    "december": [
        "dec",
        "december",
        "XII"
    ],
    "monday": [
        "h",
        "hétfő"
    ],
    "tuesday": [
        "k",
        "kedd"
    ],
    "wednesday": [
        "sze",
        "szerda"
    ],
    "thursday": [
        "cs",
        "csütörtök"
    ],
    "friday": [
        "p",
        "péntek"
    ],
    "saturday": [
        "szo",
        "szombat"
    ],
    "sunday": [
        "v",
        "vasárnap",
        "vas"
    ],
    "am": [
        "de"
    ],
    "pm": [
        "du"
    ],
    "year": [
        "év",
        "évek",
        "évvel",
        "éve"
    ],
    "month": [
        "hónap",
        "hó",
        "hónapok",
        "hónappal",
        "hónapja"
    ],
    "week": [
        "hét",
        "hetek",
        "héttel",
        "hete"
    ],
    "day": [
        "nap",
        "napok",
        "napja",
        "nappal"
    ],
    "hour": [
        "óra",
        "ó",
        "órák",
        "órája",
        "órával",
        "óráig",
        "órától"
    ],
    "minute": [
        "perc",
        "p",
        "percek",
        "perce",
        "perccel",
        "percig",
        "perctől"
    ],
    "second": [
        "másodperc",
        "mp",
        "másodpercek",
        "másodperce",
        "másodperccel",
        "másodpercig",
        "másodperctől"
    ],
    "relative-type": {
        "0 day ago": [
            "ma"
        ],
        "0 hour ago": [
            "ebben az órában"
        ],
        "0 minute ago": [
            "ebben a percben"
        ],
        "0 month ago": [
            "ez a hónap"
        ],
        "0 second ago": [
            "most"
        ],
        "0 week ago": [
            "ez a hét"
        ],
        "0 year ago": [
            "ez az év"
        ],
        "1 day ago": [
            "tegnap"
        ],
        "1 month ago": [
            "előző hónap"
        ],
        "1 week ago": [
            "előző hét"
        ],
        "1 year ago": [
            "előző év"
        ],
        "in 1 day": [
            "holnap"
        ],
        "in 1 month": [
            "következő hónap"
        ],
        "in 1 week": [
            "következő hét"
        ],
        "in 1 year": [
            "következő év"
        ],
        "2 day ago": [
            "tegnapelőtt"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) napja",
            "(\\d+) nappal ezelőtt"
        ],
        "\\1 hour ago": [
            "(\\d+) órával ezelőtt"
        ],
        "\\1 minute ago": [
            "(\\d+) perccel ezelőtt"
        ],
        "\\1 month ago": [
            "(\\d+) hónappal ezelőtt"
        ],
        "\\1 second ago": [
            "(\\d+) másodperccel ezelőtt"
        ],
        "\\1 week ago": [
            "(\\d+) héttel ezelőtt"
        ],
        "\\1 year ago": [
            "(\\d+) évvel ezelőtt"
        ],
        "in \\1 day": [
            "(\\d+) nap múlva"
        ],
        "in \\1 hour": [
            "(\\d+) óra múlva"
        ],
        "in \\1 minute": [
            "(\\d+) perc múlva"
        ],
        "in \\1 month": [
            "(\\d+) hónap múlva"
        ],
        "in \\1 second": [
            "(\\d+) másodperc múlva"
        ],
        "in \\1 week": [
            "(\\d+) hét múlva"
        ],
        "in \\1 year": [
            "(\\d+) év múlva"
        ]
    },
    "locale_specific": {},
    "skip": [
        "-a",
        "-ai",
        "-akor",
        "-e",
        "-ei",
        "-ekor",
        "-es",
        "-i",
        "-ig",
        "-je",
        "-jei",
        "-ji",
        "-kor",
        "-tól",
        "-től",
        "-áig",
        "-án",
        "-ától",
        "-éig",
        "-én",
        "-étől",
        "-ös",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "ezelőtt"
    ],
    "in": [
        "múlva"
    ],
    "simplifications": [
        {
            "egy": "1"
        }
    ]
}
